==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/outputs/HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * HyperV to AzStackHCI Replication extension model custom properties.
 * @property asrServiceUri Gets or sets the Uri of ASR.
 * @property azStackHciFabricArmId Gets or sets the ARM Id of the target AzStackHCI fabric.
 * @property azStackHciSiteId Gets or sets the ARM Id of the AzStackHCI site.
 * @property gatewayServiceUri Gets or sets the Uri of Gateway.
 * @property hyperVFabricArmId Gets or sets the ARM Id of the source HyperV fabric.
 * @property hyperVSiteId Gets or sets the ARM Id of the HyperV site.
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'HyperVToAzStackHCI'.
 * @property rcmServiceUri Gets or sets the Uri of Rcm.
 * @property resourceGroup Gets or sets the resource group.
 * @property resourceLocation Gets or sets the resource location.
 * @property sourceGatewayServiceId Gets or sets the gateway service Id of source.
 * @property sourceStorageContainerName Gets or sets the source storage container name.
 * @property storageAccountId Gets or sets the storage account Id.
 * @property storageAccountSasSecretName Gets or sets the Sas Secret of storage account.
 * @property subscriptionId Gets or sets the subscription.
 * @property targetGatewayServiceId Gets or sets the gateway service Id of target.
 * @property targetStorageContainerName Gets or sets the target storage container name.
 */
public data class HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesResponse(
    public val asrServiceUri: String,
    public val azStackHciFabricArmId: String,
    public val azStackHciSiteId: String,
    public val gatewayServiceUri: String,
    public val hyperVFabricArmId: String,
    public val hyperVSiteId: String,
    public val instanceType: String,
    public val rcmServiceUri: String,
    public val resourceGroup: String,
    public val resourceLocation: String,
    public val sourceGatewayServiceId: String,
    public val sourceStorageContainerName: String,
    public val storageAccountId: String? = null,
    public val storageAccountSasSecretName: String? = null,
    public val subscriptionId: String,
    public val targetGatewayServiceId: String,
    public val targetStorageContainerName: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datareplication.outputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesResponse):
            HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesResponse =
            HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesResponse(
                asrServiceUri = javaType.asrServiceUri(),
                azStackHciFabricArmId = javaType.azStackHciFabricArmId(),
                azStackHciSiteId = javaType.azStackHciSiteId(),
                gatewayServiceUri = javaType.gatewayServiceUri(),
                hyperVFabricArmId = javaType.hyperVFabricArmId(),
                hyperVSiteId = javaType.hyperVSiteId(),
                instanceType = javaType.instanceType(),
                rcmServiceUri = javaType.rcmServiceUri(),
                resourceGroup = javaType.resourceGroup(),
                resourceLocation = javaType.resourceLocation(),
                sourceGatewayServiceId = javaType.sourceGatewayServiceId(),
                sourceStorageContainerName = javaType.sourceStorageContainerName(),
                storageAccountId = javaType.storageAccountId().map({ args0 -> args0 }).orElse(null),
                storageAccountSasSecretName = javaType.storageAccountSasSecretName().map({ args0 ->
                    args0
                }).orElse(null),
                subscriptionId = javaType.subscriptionId(),
                targetGatewayServiceId = javaType.targetGatewayServiceId(),
                targetStorageContainerName = javaType.targetStorageContainerName(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/outputs/HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * HyperV to AzStackHCI Replication extension model custom properties.
 * @property asrServiceUri Gets or sets the Uri of ASR.
 * @property azStackHciFabricArmId Gets or sets the ARM Id of the target AzStackHCI fabric.
 * @property azStackHciSiteId Gets or sets the ARM Id of the AzStackHCI site.
 * @property gatewayServiceUri Gets or sets the Uri of Gateway.
 * @property hyperVFabricArmId Gets or sets the ARM Id of the source HyperV fabric.
 * @property hyperVSiteId Gets or sets the ARM Id of the HyperV site.
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'HyperVToAzStackHCI'.
 * @property rcmServiceUri Gets or sets the Uri of Rcm.
 * @property resourceGroup Gets or sets the resource group.
 * @property resourceLocation Gets or sets the resource location.
 * @property sourceGatewayServiceId Gets or sets the gateway service Id of source.
 * @property sourceStorageContainerName Gets or sets the source storage container name.
 * @property storageAccountId Gets or sets the storage account Id.
 * @property storageAccountSasSecretName Gets or sets the Sas Secret of storage account.
 * @property subscriptionId Gets or sets the subscription.
 * @property targetGatewayServiceId Gets or sets the gateway service Id of target.
 * @property targetStorageContainerName Gets or sets the target storage container name.
 */
public data class HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesResponse(
    public val asrServiceUri: String,
    public val azStackHciFabricArmId: String,
    public val azStackHciSiteId: String,
    public val gatewayServiceUri: String,
    public val hyperVFabricArmId: String,
    public val hyperVSiteId: String,
    public val instanceType: String,
    public val rcmServiceUri: String,
    public val resourceGroup: String,
    public val resourceLocation: String,
    public val sourceGatewayServiceId: String,
    public val sourceStorageContainerName: String,
    public val storageAccountId: String? = null,
    public val storageAccountSasSecretName: String? = null,
    public val subscriptionId: String,
    public val targetGatewayServiceId: String,
    public val targetStorageContainerName: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datareplication.outputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesResponse): HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesResponse =
            HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesResponse(
                asrServiceUri = javaType.asrServiceUri(),
                azStackHciFabricArmId = javaType.azStackHciFabricArmId(),
                azStackHciSiteId = javaType.azStackHciSiteId(),
                gatewayServiceUri = javaType.gatewayServiceUri(),
                hyperVFabricArmId = javaType.hyperVFabricArmId(),
                hyperVSiteId = javaType.hyperVSiteId(),
                instanceType = javaType.instanceType(),
                rcmServiceUri = javaType.rcmServiceUri(),
                resourceGroup = javaType.resourceGroup(),
                resourceLocation = javaType.resourceLocation(),
                sourceGatewayServiceId = javaType.sourceGatewayServiceId(),
                sourceStorageContainerName = javaType.sourceStorageContainerName(),
                storageAccountId = javaType.storageAccountId().map({ args0 -> args0 }).orElse(null),
                storageAccountSasSecretName = javaType.storageAccountSasSecretName().map({ args0 ->
                    args0
                }).orElse(null),
                subscriptionId = javaType.subscriptionId(),
                targetGatewayServiceId = javaType.targetGatewayServiceId(),
                targetStorageContainerName = javaType.targetStorageContainerName(),
            )
    }
}
